<?php
namespace Indeed\Uap;

class ElCheck
{
    /**
     * @var string
     */
    private $purchaseCode         = '';// input from user
    /**
     * @var string
     */
    private $pluginId             = '16527729';
    /**
     * @var string
     */
    private $ajax                 = 'uap_el_check_get_url_ajax';//
    /**
     * @var string
     */
    private $wpIndeedUrlEndpoint  = 'https://wpindeed.com/wp-content/plugins/wpindeed-envato/input.php'; // wpIndeed Server

    /**
     * @var string
     */
    private $optionName           = 'uap_license_set';
    /**
     * @var string
     */
    private $hashOptionName       = 'uap_license_hash';
    /**
     * @var string
     */
    private $purchaseOptionName   = 'uap_envato_code';
    /**
     * @var string
     */
    private $redirectBackUri      = ''; /// dynamicly generated
    /**
     * @var string
     */
    private $confirmationUri      = '';/// dynamicly generated
    /**
     * @var string
     */
    private $ajaxRevoke           = 'uap_revoke_license';//
    /**
     * @var string
     */
    private $wpIndeedRevokeEndpoint = 'https://wpindeed.com/wp-admin/admin-ajax.php/';

    /**
     * @param none
     * @return none
     */
    public function __construct()
    {
        add_action( 'wp_ajax_' . $this->ajax, [ $this, 'ajax' ] );
        add_action( 'wp_ajax_' . $this->ajaxRevoke, [ $this, 'revoke' ] );
        $this->redirectBackUri = admin_url( 'admin.php?page=ultimate_affiliates_pro&tab=help' );
        $this->confirmationUri = UAP_URL . 'admin/elc_response.php';
    }

    /**
     * @param none
     * @return none
     */
    public function ajax()
    {
        if ( !indeedIsAdmin() ){
            echo 0;
            die;
        }
        if ( !uapAdminVerifyNonce() ){
            echo 0;
            die;
        }
        if ( empty( $_POST['purchase_code'] ) ){
            die;
        }
        update_option( 'uap_envato_code', esc_sql($_POST['purchase_code']) );
        echo $this->getRedirectLinkToWpIndeed( esc_sql( $_POST['purchase_code'] ) );
        die;
    }

    /**
     * @param none
     * @return none
     */
    public function response()
    {
        if ( !empty( $_POST['response'] ) && $_POST['response']>0 && !empty( $_POST['hash'] ) ){
            update_option( $this->optionName, 1 );
            update_option( $this->hashOptionName, esc_sql( $_POST['hash'] ) );
            return;
        }
        update_option( $this->optionName, 0 );
    }

    /**
     * @param string
     * @return string
     */
    public function getRedirectLinkToWpIndeed( $purchaseCode='' )
    {
        if ( !$purchaseCode ){
            return;
        }
        // save purchase code into db
        update_option( $this->purchaseOptionName, $purchaseCode );
        $url = add_query_arg( [
                          'indeed-auth-app'       => 'check_license',
                          'purchase_code'         => $purchaseCode,
                          'plugin_id'             => $this->pluginId,
                          'return_url'            => urlencode($this->redirectBackUri),
                          'confirmation_url'      => urlencode($this->confirmationUri),
        ], $this->wpIndeedUrlEndpoint );
        return $url;
    }

    /**
     * @param int
     * @return string
     */
    public function responseCodeToMessage( $code=0, $errorClass='', $successClass='', $langCode )
    {
        switch ( $code ){
            case 1:
              return "<div class='$successClass'>" . __('Your plugin has been successfully activated the License.', $langCode ) . "</div>";
              break;
            case 0:
              return "<div class='$errorClass'>" . __('Bad input data. Please try again later!', $langCode ) . "</div>";
              break;
            case -1:
              return "<div class='$errorClass'>" . __('Envato API Server may be done for a moment. Please try again later', $langCode ) . "</div>";
              break;
            case -2:
              return "<div class='$errorClass'>" . __('Submitted Purchase Code is invalid.', $langCode ) . "</div>";
              break;
            case -3:
              return "<div class='$errorClass'>" . __('Submitted Purchase Code does not match with Current product.', $langCode ) . "</div>";
              break;
        }
    }

    /**
     * @param none
     * @return bool
     */
    public function revoke()
    {
        $purchaseCode = get_option( 'uap_envato_code' );
        $referrence = get_option( 'siteurl' );
        update_option( $this->optionName, 0 );
        update_option( $this->hashOptionName, 0 );
        update_option( 'uap_envato_code', '' );
        $header= [
          'Content-Type: application/x-www-form-urlencoded; charset=UTF-8',
          'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:72.0) Gecko/20100101 Firefox/72.0',
          'Accept: */*',
          'Accept-Language: en-US,en;q=0.5',
          'Content-Type: application/x-www-form-urlencoded; charset=UTF-8',
          'X-Requested-With: XMLHttpRequest',
        ];
        $builder= http_build_query([
           'action'         => "wpindeed_envato_revoke_license",
           'purchase_code'  => $purchaseCode,
           'referrence'     => $referrence,
        ]);


        $ch = curl_init( $this->wpIndeedRevokeEndpoint );
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $builder);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST,'POST');
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER,1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST,2);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, false);
        curl_setopt($ch, CURLINFO_HEADER_OUT, 1);
        $res = curl_exec($ch);
        curl_close($ch);
        echo 1;
        die;
    }
}
